/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.framework;



import javax.print.DocPrintJob;
import javax.print.event.PrintJobAdapter;
import javax.print.event.PrintJobEvent;



/**
 * This class performs a waiting for a printer job. We need to wait for a
 * PostScript SW printer to finish printing because the conversion to a PNG
 * files should be done when the .ps files are created and closed.
 * 
 * @author Pavel Tisnovsky
 */
public class PrintJobWatcher
{
    /**
     * Set to true if it is safe to close the print job's input stream
     */
    boolean printJobDone = false;

    /**
     * Constructor.
     * 
     * @param job
     *            print job that can print a specified document with a set of
     *            job attributes
     */
    public PrintJobWatcher(DocPrintJob job)
    {
        // Add a listener to the print job
        job.addPrintJobListener(new PrintJobAdapter()
        {
            @Override
            /**
             * @see PrintJobAdapter#printJobCancelled
             */
            public void printJobCanceled(PrintJobEvent pje)
            {
                allDone();
            }

            @Override
            /**
             * @see PrintJobAdapter#printJobCompleted
             */
            public void printJobCompleted(PrintJobEvent pje)
            {
                allDone();
            }

            @Override
            /**
             * @see PrintJobAdapter#printJobFailed
             */
            public void printJobFailed(PrintJobEvent pje)
            {
                allDone();
            }

            @Override
            /**
             * @see PrintJobAdapter#printJobNoMoreEvents
             */
            public void printJobNoMoreEvents(PrintJobEvent pje)
            {
                allDone();
            }

            /**
             * Called when printing is canceled or finished.
             */
            void allDone()
            {
                synchronized (PrintJobWatcher.this)
                {
                    // set a flag
                    PrintJobWatcher.this.printJobDone = true;
                    // and notify PrintJobWatcher
                    PrintJobWatcher.this.notifyAll();
                }
            }
        });
    }

    /**
     * Called from the gfx. test framework.
     */
    public synchronized void waitForDone()
    {
        try
        {
            // thread wait
            while (!this.printJobDone)
            {
                wait();
            }
        }
        // thread could be interrupted
        catch (InterruptedException e)
        {
            e.printStackTrace();
        }
    }
}
