/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.gfxtest.testsuites;



import java.awt.Graphics2D;
import java.awt.geom.Area;



import org.gfxtest.framework.CommonAreaOperations;
import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test checks the process of creating and rendering new geometric shapes
 * represented by an Area class. Areas are drawn using various stroke or fill
 * method.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.AREA)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class Areas extends GfxTest
{
    /**
     * Test the result of creating area using an opened quadratic Bezier curve.
     * Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testQuadraticCurveStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from open quadratic curve
        Area area = CommonAreaOperations.createAreaFromQuadraticCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtQuadraticCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened quadratic Bezier curve.
     * Area is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testQuadraticCurveWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area from open quadratic curve
        Area area = CommonAreaOperations.createAreaFromQuadraticCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtQuadraticCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened quadratic Bezier curve.
     * Area is rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testQuadraticCurveExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area from open quadratic curve
        Area area = CommonAreaOperations.createAreaFromQuadraticCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtQuadraticCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened quadratic curve.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testQuadraticCurveColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area from open quadratic curve
        Area area = CommonAreaOperations.createAreaFromQuadraticCurve(image);
        // draw the area
        graphics2d.fill(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtQuadraticCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened cubic curve.
     * Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCubicCurveStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from open cubic curve
        Area area = CommonAreaOperations.createAreaFromCubicCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened cubic curve.
     * Area is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCubicCurveWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area from open cubic curve
        Area area = CommonAreaOperations.createAreaFromCubicCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened cubic curve.
     * Area is rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCubicCurveExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area from open cubic curve
        Area area = CommonAreaOperations.createAreaFromCubicCurve(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an opened cubic curve.
     * 
     * @param image
     *            image to which area is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCubicCurveColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area from open cubic curve
        Area area = CommonAreaOperations.createAreaFromCubicCurve(image);
        // draw the area
        graphics2d.fill(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an open Path constructed from line
     * segments. Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOpenPathStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from open path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromOpenPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an open Path constructed from line
     * segments. Area is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOpenPathWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area from open path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromOpenPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an open Path constructed from line
     * segments. Area is rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOpenPathExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area from open path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromOpenPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using an open Path constructed from line
     * segments. Area is rendered using color paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testOpenPathColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area from open path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromOpenPath(image);
        // draw the area
        graphics2d.fill(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a closed Path constructed from
     * line segments. Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from closed path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromClosedPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a closed Path constructed from
     * line segments. Area is rendered using wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area from closed path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromClosedPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a closed Path constructed from
     * line segments. Area is rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke extra width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area from closed path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromClosedPath(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a closed Path constructed from
     * line segments. Area is rendered using color paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area from open path constructed from line segment
        Area area = CommonAreaOperations.createAreaFromClosedPath(image);
        // draw the area
        graphics2d.fill(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtCubicCurveControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a simple Line2D object.
     * Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testAreaConstructedFromLine2DStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // create area from a simple Line2D object
        Area area = CommonAreaOperations.createAreaFromLine2D(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtLineControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a simple Line2D object.
     * Area is rendered using extra wide stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testAreaConstructedFromLine2DWideExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // create area from a simple Line2D object
        Area area = CommonAreaOperations.createAreaFromLine2D(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtLineControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a simple Line2D object.
     * Area is rendered using color paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testAreaConstructedFromLine2DColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create area from a simple Line2D object
        Area area = CommonAreaOperations.createAreaFromLine2D(image);
        // draw the area
        graphics2d.fill(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtLineControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a rectangle object.
     * Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testAreaConstructedFromRectangleStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from rectangle
        Area area = CommonAreaOperations.createAreaFromRectangle(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtRectangleControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Test the result of creating area using a polygon object.
     * Area is rendered using stroke paint.
     * 
     * @param image
     *            image to which line is to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testAreaConstructedFromPolygonStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // create area from polygon
        Area area = CommonAreaOperations.createAreaFromPolygon(image);
        // draw the area
        graphics2d.draw(area);
        // draw crosses at control points
        CommonAreaOperations.drawCrossesAtPolygonControlPoints(image, graphics2d);
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new Areas().runTestSuite(args);
    }

}
