/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
 */

package org.gfxtest.testsuites;

import java.awt.Graphics2D;



import org.gfxtest.framework.CommonClippingOperations;
import org.gfxtest.framework.CommonRenderingStyles;
import org.gfxtest.framework.CommonShapesRenderer;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;

/**
 * This test check if clipping is working correctly for an empty, filled
 * and textured circle which is clipped by a convex polygonal shape.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@Transformation(Transformations.NONE)
@GraphicsPrimitive(GraphicsPrimitives.CIRCLE)
@Zoom(1)
public class ClippingCircleByConvexPolygonalShape extends GfxTest
{
    /**
     * Prepare canvas for the rendering.
     *
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     */
    private static void basicSetupForRendering(TestImage image, Graphics2D graphics2d)
    {
        // create clip area which is constructed from the convex polygonal shape
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
    }

    /**
     * Draw empty circle clipped by a convex polygonal shape.
     *
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     */
    private static void drawEmptyCircleClippedByPolygonalShape(TestImage image, Graphics2D graphics2d)
    {
        // prepare canvas for the rendering
        basicSetupForRendering(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // draw the area
        CommonShapesRenderer.drawCircle(image, graphics2d);
    }

    /**
     * Draw filled circle clipped by a convex polygonal shape.
     *
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     */
    private static void drawFilledCircleClippedByPolygonalShape(TestImage image, Graphics2D graphics2d)
    {
        // prepare canvas for the rendering
        basicSetupForRendering(image, graphics2d);
        // fill the area
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with black color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintBlack(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillBlackColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with red color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintRed(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillRedColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with green color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintGreen(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillGreenColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with blue color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintBlue(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillBlueColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with magenta color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintMagenta(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillMagentaColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with cyan color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintCyan(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillCyanColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with yellow color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintYellow(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillYellowColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Draw circle clipped by a convex polygonal shape. Circle is drawn using alpha
     * paint with white color and selected transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @param transparency
     *            selected transparency (0..100 percent)
     */
    private void drawCircleClippedByPolygonalShapeAlphaPaintWhite(TestImage image, Graphics2D graphics2d, int transparency)
    {
        // render clip polygon
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setTransparentFillWhiteColor(graphics2d, transparency);
        // create clip area
        CommonClippingOperations.createClipUsingConvexPolygonalShape(image, graphics2d);
        // fill the shape
        CommonShapesRenderer.drawFilledCircle(image, graphics2d);
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using stroke paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set clip region and draw the circle
        drawEmptyCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using wide stroke paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeThickWidth(graphics2d);
        // set clip region and draw the circle
        drawEmptyCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using extra wide stroke paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeExtraWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeExtraThickWidth(graphics2d);
        // set clip region and draw the circle
        drawEmptyCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using zero wide stroke paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeZeroWideStrokePaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke width
        CommonRenderingStyles.setStrokeZeroThick(graphics2d);
        // set clip region and draw the circle
        drawEmptyCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using color paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeColorPaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics2d);
        // set fill color
        CommonRenderingStyles.setFillColor(graphics2d);
        // create clip shape and fill the shape
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with black color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlack000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlack(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with black color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlack025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlack(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with black color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlack050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlack(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with black color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlack075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlack(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with black color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlack100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlack(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with red color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintRed000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintRed(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with red color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintRed025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintRed(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with red color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintRed050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintRed(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with red color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintRed075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintRed(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with red color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintRed100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintRed(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with green color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintGreen000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintGreen(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with green color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintGreen025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintGreen(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with green color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintGreen050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintGreen(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with green color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintGreen075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintGreen(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with green color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintGreen100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintGreen(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with blue color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlue000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlue(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with blue color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlue025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlue(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with blue color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlue050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlue(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with blue color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlue075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlue(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with blue color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintBlue100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintBlue(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with magenta color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintMagenta000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintMagenta(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with magenta color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintMagenta025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintMagenta(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with magenta color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintMagenta050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintMagenta(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with magenta color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintMagenta075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintMagenta(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with magenta color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintMagenta100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintMagenta(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintCyan000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintCyan(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintCyan025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintCyan(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintCyan050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintCyan(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintCyan075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintCyan(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintCyan100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintCyan(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintYellow000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintYellow(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintYellow025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintYellow(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintYellow050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintYellow(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintYellow075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintYellow(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with cyan color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintYellow100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintYellow(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with white color at 0% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintWhite000(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 0% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintWhite(image, graphics2d, 0);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with white color at 25% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintWhite025(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 25% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintWhite(image, graphics2d, 25);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with white color at 50% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintWhite050(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 50% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintWhite(image, graphics2d, 50);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with white color at 75% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintWhite075(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 75% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintWhite(image, graphics2d, 75);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a convex polygonal shape. Circle is
     * rendered using alpha paint with white color at 100% transparency.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeAlphaPaintWhite100(TestImage image, Graphics2D graphics2d)
    {
        // draw circle clipped by convex polygonal shape using alpha paint with 100% transparency
        drawCircleClippedByPolygonalShapeAlphaPaintWhite(image, graphics2d, 100);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using horizontal gradient paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeHorizontalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygonal which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set horizontal gradient paint
        CommonRenderingStyles.setHorizontalGradientFill(image, graphics2d);
        // set clip region and draw the circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using vertical gradient paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeVerticalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygonal which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set vertical gradient paint
        CommonRenderingStyles.setVerticalGradientFill(image, graphics2d);
        // set clip region and draw the circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using diagonal gradient paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeDiagonalGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygonal which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set diagonal gradient paint
        CommonRenderingStyles.setDiagonalGradientFill(image, graphics2d);
        // set clip region and draw the circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using radial gradient paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeRadialGradientPaint(TestImage image, Graphics2D graphics2d)
    {
        // render a polygonal which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set radial gradient paint
        CommonRenderingStyles.setRadialGradientFill(image, graphics2d);
        // set clip region and draw the circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeCheckerTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingCheckerTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeDiagonalCheckerTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingDiagonalCheckerTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeGridTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingGridTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeDiagonalGridTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingDiagonalGridTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeColorDotsTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingColorDotsTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeHorizontalStripesTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingHorizontalStripesTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeVerticalStripesTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingVerticalStripesTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeDiagonalStripesTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingDiagonalStripesTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeHorizontalColorStripesTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingHorizontalColorStripesTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeVerticalColorStripesTexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingVerticalColorStripesTexture(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeRGB1TexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingRGBTexture1(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeRGB2TexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingRGBTexture2(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Check if circle shape could be clipped by a polygonal shape. Circle is
     * rendered using texture paint.
     * 
     * @param image
     *            work image
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClipCircleByPolygonalShapeRGB3TexturePaint(TestImage image, Graphics2D graphics2d)
    {
        // render clip polygon which is used as a base for clip shape
        CommonClippingOperations.renderConvexClipPolygon(image, graphics2d);
        // set the texture
        CommonRenderingStyles.setTextureFillUsingRGBTexture3(image, graphics2d);
        // set clip region and render filled circle
        drawFilledCircleClippedByPolygonalShape(image, graphics2d);
        // test result
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            graphics test configuration
     */
    public static void main(String[] args)
    {
        new ClippingCircleByConvexPolygonalShape().runTestSuite(args);
    }
}
