/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.BasicStroke;
import java.awt.Graphics2D;



import org.gfxtest.callbacks.PolylineDrawCallbacks;
import org.gfxtest.framework.ColorPalette;
import org.gfxtest.framework.GrayscalePalette;
import org.gfxtest.framework.HSBPalette;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test suite checks rendering of various polylines.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.POLYLINE)
@RenderStyle(RenderStyles.NORMAL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestPolylines extends PrintTest
{
    /**
     * Method which renders set of polylines using various colors and stroke
     * styles. For each polyline, the callback function/method is called to
     * perform all required setup.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @param step
     *            between two near polylines
     * @param polylineDrawCallbacks
     *            class containing set of callback methods
     */
    private static void drawPolylines(TestImage image, Graphics2D graphics, int step, PolylineDrawCallbacks polylineDrawCallbacks)
    {
        // setup rendering
        polylineDrawCallbacks.setup(image, graphics);

        // image width and height
        final int width = image.getWidth();
        final int height = image.getHeight();

        // horizontal coordinates of polyline endpoints
        int x1 = BORDER;
        int x2 = width - BORDER;

        // vertical coordinates of polyline endpoints
        int y1 = BORDER;
        int y2 = height - BORDER;

        // index to color palette
        int colorIndex = 0;

        // draw all polylines onto a paper
        while (x1 < x2 - BORDER && y1 < y2 - BORDER)
        {
            // setup can be made for each polyline
            polylineDrawCallbacks.iterationCallBack(x1, y1, x2, y2, colorIndex++);
            // render the new polyline
            int xpoints[] = {x1, x2, x2, x1};
            int ypoints[] = {y1, y1, y2, y2};
            graphics.drawPolyline(xpoints, ypoints, 4);
            // setup coordinates for the next polyline
            x1 += step;
            y1 += step;
            x2 -= step;
            y2 -= step;
        }

        // cleanup rendering
        polylineDrawCallbacks.cleanup();
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are set to black.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesBasicStyle(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesColorPalette(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set polyline color
                this.graphics.setColor(ColorPalette.getColor(index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesGrayScale(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute grayscale value
                float gray = (y1 - BORDER) * 4.0f / this.image.getHeight();
                // set polyline color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a hue palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesColorScale(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute hue value
                float hue = (y1 - BORDER) * 4.0f / this.image.getHeight();
                // set polyline color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidth(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinBevel(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinMiter(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinRound(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            float strokeWidth = 0.0f;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // set new stroke width
                this.strokeWidth = this.strokeWidth < MAX_STROKE_WIDTH ? this.strokeWidth + STROKE_WIDTH_DELTA : this.strokeWidth;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesColorPaletteInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set polyline color
                this.graphics.setColor(ColorPalette.getColor(MAX_COLOR_INDEX - index));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a hue palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesColorScaleInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute hue value
                float hue = 1.0f - (y1 - BORDER) * 4.0f / this.image.getHeight();
                // set polyline color
                this.graphics.setColor(HSBPalette.createHsbColor(hue));
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesGrayScaleInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP, new PolylineDrawCallbacks()
        {
            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // compute grayscale value
                float gray = 1.0f - (y1 - BORDER) * 4.0f / this.image.getHeight();
                // set polyline color
                this.graphics.setColor(GrayscalePalette.createGrayscaleColor(gray));
                return;
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth));
                // and change it for the next iteration
                changeStrokeWidth();
                return;
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_BUTT.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapButtJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_BUTT, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_ROUND.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapRoundJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to bevel style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinBevelInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_BEVEL));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to miter style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinMiterInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_MITER));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });
        

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test basic behavior of method Graphics.drawPolyline(). Polyline are
     * rendered with default width and default end caps. Color of all rendered
     * polylines are selected from a grayscale palette.
     * Join style is set to round style and end caps is set to CAP_SQUARE.
     * 
     * @param image
     *            image to which polylines are to be drawn
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testDrawPolylinesChangeWidthCapSquareJoinRoundInv(TestImage image, Graphics2D graphics2d)
    {
        drawPolylines(image, graphics2d, POLYLINE_STEP * 4 / 3, new PolylineDrawCallbacks()
        {
            /**
             * Stroke width.
             */
            private float strokeWidth = MAX_STROKE_WIDTH - 2;

            /**
             * Callback function called before each polyline is rendered.
             */
            @Override
            public void iterationCallBack(int x1, int y1, int x2, int y2, int index)
            {
                // set stroke width
                this.graphics.setStroke(new BasicStroke(this.strokeWidth, BasicStroke.CAP_SQUARE, BasicStroke.JOIN_ROUND));
                // and change it for the next iteration
                changeStrokeWidth();
            }

            /**
             * Changes stroke width.
             */
            private void changeStrokeWidth()
            {
                // decrease stroke width
                this.strokeWidth -= STROKE_WIDTH_DELTA;
                // stroke width should not be less than zero
                if (this.strokeWidth < MIN_STROKE_WIDTH)
                {
                    this.strokeWidth = MIN_STROKE_WIDTH;
                }
            }
        });

        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestPolylines().runTestSuite(args);
    }

}
